==> aws-cdk.aws-secretsmanager-1.64.0.tar.gz: package/test/test.secret.d.ts <==
import { Test } from 'nodeunit';
declare const _default: {
    'default secret'(test: Test): void;
    'set removalPolicy to secret'(test: Test): void;
    'secret with kms'(test: Test): void;
    'secret with generate secret string options'(test: Test): void;
    'templated secret string'(test: Test): void;
    grantRead(test: Test): void;
    'grantRead with version label constraint'(test: Test): void;
    grantWrite(test: Test): void;
    'grantWrite with kms'(test: Test): void;
    secretValue(test: Test): void;
    'import by secretArn'(test: Test): void;
    'import by secretArn throws if ARN is malformed'(test: Test): void;
    'import by attributes'(test: Test): void;
    'import by secret name'(test: Test): void;
    'import by secret name with grants'(test: Test): void;
    'can attach a secret with attach()'(test: Test): void;
    'throws when trying to attach a target multiple times to a secret'(test: Test): void;
    'add a rotation schedule to an attached secret'(test: Test): void;
    'throws when specifying secretStringTemplate but not generateStringKey'(test: Test): void;
    'throws when specifying generateStringKey but not secretStringTemplate'(test: Test): void;
    'equivalence of SecretValue and Secret.fromSecretAttributes'(test: Test): void;
    'can add to the resource policy of a secret'(test: Test): void;
    'fails if secret policy has no actions'(test: Test): void;
    'fails if secret policy has no IAM principals'(test: Test): void;
};
export = _default;

==> aws-cdk.aws-secretsmanager-1.66.0.tar.gz: package/test/test.secret.d.ts <==
import { Test } from 'nodeunit';
declare const _default: {
    'default secret'(test: Test): void;
    'set removalPolicy to secret'(test: Test): void;
    'secret with kms'(test: Test): void;
    'secret with generate secret string options'(test: Test): void;
    'templated secret string'(test: Test): void;
    grantRead(test: Test): void;
    'grantRead with version label constraint'(test: Test): void;
    grantWrite(test: Test): void;
    'grantWrite with kms'(test: Test): void;
    secretValue(test: Test): void;
    'import by secretArn'(test: Test): void;
    'import by secretArn throws if ARN is malformed'(test: Test): void;
    'import by secretArn supports secret ARNs without suffixes'(test: Test): void;
    'import by secretArn supports tokens for ARNs'(test: Test): void;
    'import by attributes'(test: Test): void;
    'import by secret name'(test: Test): void;
    'import by secret name with grants'(test: Test): void;
    'can attach a secret with attach()'(test: Test): void;
    'throws when trying to attach a target multiple times to a secret'(test: Test): void;
    'add a rotation schedule to an attached secret'(test: Test): void;
    'throws when specifying secretStringTemplate but not generateStringKey'(test: Test): void;
    'throws when specifying generateStringKey but not secretStringTemplate'(test: Test): void;
    'equivalence of SecretValue and Secret.fromSecretAttributes'(test: Test): void;
    'can add to the resource policy of a secret'(test: Test): void;
    'fails if secret policy has no actions'(test: Test): void;
    'fails if secret policy has no IAM principals'(test: Test): void;
};
export = _default;
